==> jdk-21.0.9.10.1p0v0.tgz: jdk.localedata/sun/util/resources/cldr/ext/CurrencyNames_lag.java <==
/*
 * Copyright (c) 2012, 2026, Oracle and/or its affiliates. All rights reserved.
 * DO NOT ALTER OR REMOVE COPYRIGHT NOTICES OR THIS FILE HEADER.
 *
 * This code is free software; you can redistribute it and/or modify it
 * under the terms of the GNU General Public License version 2 only, as
 * published by the Free Software Foundation.  Oracle designates this
 * particular file as subject to the "Classpath" exception as provided
 * by Oracle in the LICENSE file that accompanied this code.
 *
 * This code is distributed in the hope that it will be useful, but WITHOUT
 * ANY WARRANTY; without even the implied warranty of MERCHANTABILITY or
 * FITNESS FOR A PARTICULAR PURPOSE.  See the GNU General Public License
 * version 2 for more details (a copy is included in the LICENSE file that
 * accompanied this code).
 *
 * You should have received a copy of the GNU General Public License version
 * 2 along with this work; if not, write to the Free Software Foundation,
 * Inc., 51 Franklin St, Fifth Floor, Boston, MA 02110-1301 USA.
 *
 * Please contact Oracle, 500 Oracle Parkway, Redwood Shores, CA 94065 USA
 * or visit www.oracle.com if you need additional information or have any
 * questions.
 */

/*
 * COPYRIGHT AND PERMISSION NOTICE
 *
 * Copyright (c) 1991-2022 Unicode, Inc. All rights reserved.
 * Distributed under the Terms of Use in https://www.unicode.org/copyright.html.
 *
 * Permission is hereby granted, free of charge, to any person obtaining
 * a copy of the Unicode data files and any associated documentation
 * (the "Data Files") or Unicode software and any associated documentation
 * (the "Software") to deal in the Data Files or Software
 * without restriction, including without limitation the rights to use,
 * copy, modify, merge, publish, distribute, and/or sell copies of
 * the Data Files or Software, and to permit persons to whom the Data Files
 * or Software are furnished to do so, provided that either
 * (a) this copyright and permission notice appear with all copies
 * of the Data Files or Software, or
 * (b) this copyright and permission notice appear in associated
 * Documentation.
 *
 * THE DATA FILES AND SOFTWARE ARE PROVIDED "AS IS", WITHOUT WARRANTY OF
 * ANY KIND, EXPRESS OR IMPLIED, INCLUDING BUT NOT LIMITED TO THE
 * WARRANTIES OF MERCHANTABILITY, FITNESS FOR A PARTICULAR PURPOSE AND
 * NONINFRINGEMENT OF THIRD PARTY RIGHTS.
 * IN NO EVENT SHALL THE COPYRIGHT HOLDER OR HOLDERS INCLUDED IN THIS
 * NOTICE BE LIABLE FOR ANY CLAIM, OR ANY SPECIAL INDIRECT OR CONSEQUENTIAL
 * DAMAGES, OR ANY DAMAGES WHATSOEVER RESULTING FROM LOSS OF USE,
 * DATA OR PROFITS, WHETHER IN AN ACTION OF CONTRACT, NEGLIGENCE OR OTHER
 * TORTIOUS ACTION, ARISING OUT OF OR IN CONNECTION WITH THE USE OR
 * PERFORMANCE OF THE DATA FILES OR SOFTWARE.
 *
 * Except as contained in this notice, the name of a copyright holder
 * shall not be used in advertising or otherwise to promote the sale,
 * use or other dealings in these Data Files or Software without prior
 * written authorization of the copyright holder.
 */

package sun.util.resources.cldr.ext;

import sun.util.resources.OpenListResourceBundle;

public class CurrencyNames_lag extends OpenListResourceBundle {
    @Override
    protected final Object[][] getContents() {
        final Object[][] data = new Object[][] {
            { "TZS", "TSh" },
            { "aed", "Dirih\u00e1amu ya \u0244temi wa K\u0268ar\u00e1abu" },
            { "aoa", "Kw\u00e1anza ya Ang\u00f3ola" },
            { "aud", "D\u00f3ola ya Ausitereel\u00eda" },
            { "bhd", "Din\u00e1ari ya Bahar\u00e9eni" },
            { "bif", "Far\u00e1anga ya Bur\u00faundi" },
            { "bwp", "P\u00faula ya Botisw\u00e1ana" },
            { "cad", "D\u00f3ola ya K\u00e1nada" },
            { "cdf", "Far\u00e1anga ya K\u00f3ongo" },
            { "chf", "Far\u00e1aka ya Usw\u00edisi" },
            { "cny", "Y\u00faani Renim\u00ednibi ya Ch\u00edina" },
            { "cve", "Esik\u00faudo ya Kepuv\u00e9ede" },
            { "djf", "Far\u00e1anga ya Jib\u00f3uti" },
            { "dzd", "Din\u00e1airi ya Alij\u00e9ria" },
            { "egp", "P\u00e1undi ya M\u00edsiri" },
            { "ern", "N\u00e1k\u0268fa ya Eriterea" },
            { "etb", "B\u00ediri ya \u0244hab\u00e9eshi" },
            { "eur", "Y\u00fauro" },
            { "gbp", "P\u00e1undi ya \u0244\u0268ng\u0268r\u00e9esa" },
            { "ghc", "S\u00e9edi ya G\u00e1ana" },
            { "gmd", "Dal\u00e1asi ya G\u00e1mbia" },
            { "gns", "Far\u00e1anga ya G\u00edine" },
            { "inr", "Rup\u00eda ya \u00cdndia" },
            { "jpy", "Y\u00e9eni ya Jap\u00e1ani" },
            { "kes", "Shil\u00edingi ya K\u00e9enya" },
            { "kmf", "Far\u00e1anga ya Kom\u00f3oro" },
            { "lrd", "D\u00f3ola ya Lib\u00e9ria" },
            { "lsl", "L\u00f3oti ya Les\u00f3oto" },
            { "lyd", "Din\u00e1ari ya L\u00edbia" },
            { "mad", "Dirih\u00e1amu ya Mor\u00f3oko" },
            { "mga", "Mp\u00eda ya bukini" },
            { "mro", "Ungw\u00ediya ya Morit\u00e1nia (1973\u20132017)" },
            { "mru", "Ungw\u00ediya ya Morit\u00e1nia" },
            { "mur", "Rup\u00eda ya Mor\u00edisi" },
            { "mwk", "Kw\u00e1acha ya Mal\u00e1awi" },
            { "mzm", "Metik\u00e1ali ya Musumb\u00ediji" },
            { "nad", "D\u00f3ola ya Nam\u00edbia" },
            { "ngn", "Na\u00edira ya Niij\u00e9ria" },
            { "rwf", "Far\u00e1anga ya Rw\u00e1anda" },
            { "sar", "Riy\u00e1ali ya Saud\u00eda" },
            { "scr", "Rup\u00eda ya Shelish\u00e9eli" },
            { "sdg", "P\u00e1undi ya Sud\u00e1ani" },
            { "shp", "P\u00e1undi ya M\u0289takat\u00edifu Hel\u00e9ena" },
            { "sll", "Le\u00f3oni" },
            { "sos", "Shil\u00edingi ya Som\u00e1lia" },
            { "std", "D\u00f3bura ya SaoT\u00f3ome na Pir\u00ednsipe (1977\u20132017)" },
            { "stn", "D\u00f3bura ya SaoT\u00f3ome na Pir\u00ednsipe" },
            { "szl", "Lileng\u00e9eni" },
            { "tnd", "Din\u00e1ari ya Tun\u00edsia" },
            { "tzs", "Shil\u00edingi ya Taansan\u00eda" },
            { "ugx", "Shil\u00edingi ya Ug\u00e1anda" },
            { "usd", "D\u00f3ola ya Amer\u0268\u0301ka" },
            { "xaf", "Far\u00e1anga ya CFA BEAC" },
            { "xof", "Far\u00e1anga ya CFA BCEAO" },
            { "zar", "R\u00e1andi ya Af\u0268r\u0268ka ya Saame" },
            { "zmk", "Kw\u00e1cha ya S\u00e1mbia (1968\u20132012)" },
            { "zmw", "Kw\u00e1cha ya S\u00e1mbia" },
            { "zwd", "D\u00f3ola ya Simb\u00e1abwe" },
        };
        return data;
    }
}

==> jdk-25.0.1.8.1p1v0.tgz: jdk.localedata/sun/util/resources/cldr/ext/CurrencyNames_lag.java <==
/*
 * Copyright (c) 2012, 2026, Oracle and/or its affiliates. All rights reserved.
 * DO NOT ALTER OR REMOVE COPYRIGHT NOTICES OR THIS FILE HEADER.
 *
 * This code is free software; you can redistribute it and/or modify it
 * under the terms of the GNU General Public License version 2 only, as
 * published by the Free Software Foundation.  Oracle designates this
 * particular file as subject to the "Classpath" exception as provided
 * by Oracle in the LICENSE file that accompanied this code.
 *
 * This code is distributed in the hope that it will be useful, but WITHOUT
 * ANY WARRANTY; without even the implied warranty of MERCHANTABILITY or
 * FITNESS FOR A PARTICULAR PURPOSE.  See the GNU General Public License
 * version 2 for more details (a copy is included in the LICENSE file that
 * accompanied this code).
 *
 * You should have received a copy of the GNU General Public License version
 * 2 along with this work; if not, write to the Free Software Foundation,
 * Inc., 51 Franklin St, Fifth Floor, Boston, MA 02110-1301 USA.
 *
 * Please contact Oracle, 500 Oracle Parkway, Redwood Shores, CA 94065 USA
 * or visit www.oracle.com if you need additional information or have any
 * questions.
 */

/*
 * COPYRIGHT AND PERMISSION NOTICE
 *
 * Copyright (c) 1991-2022 Unicode, Inc. All rights reserved.
 * Distributed under the Terms of Use in https://www.unicode.org/copyright.html.
 *
 * Permission is hereby granted, free of charge, to any person obtaining
 * a copy of the Unicode data files and any associated documentation
 * (the "Data Files") or Unicode software and any associated documentation
 * (the "Software") to deal in the Data Files or Software
 * without restriction, including without limitation the rights to use,
 * copy, modify, merge, publish, distribute, and/or sell copies of
 * the Data Files or Software, and to permit persons to whom the Data Files
 * or Software are furnished to do so, provided that either
 * (a) this copyright and permission notice appear with all copies
 * of the Data Files or Software, or
 * (b) this copyright and permission notice appear in associated
 * Documentation.
 *
 * THE DATA FILES AND SOFTWARE ARE PROVIDED "AS IS", WITHOUT WARRANTY OF
 * ANY KIND, EXPRESS OR IMPLIED, INCLUDING BUT NOT LIMITED TO THE
 * WARRANTIES OF MERCHANTABILITY, FITNESS FOR A PARTICULAR PURPOSE AND
 * NONINFRINGEMENT OF THIRD PARTY RIGHTS.
 * IN NO EVENT SHALL THE COPYRIGHT HOLDER OR HOLDERS INCLUDED IN THIS
 * NOTICE BE LIABLE FOR ANY CLAIM, OR ANY SPECIAL INDIRECT OR CONSEQUENTIAL
 * DAMAGES, OR ANY DAMAGES WHATSOEVER RESULTING FROM LOSS OF USE,
 * DATA OR PROFITS, WHETHER IN AN ACTION OF CONTRACT, NEGLIGENCE OR OTHER
 * TORTIOUS ACTION, ARISING OUT OF OR IN CONNECTION WITH THE USE OR
 * PERFORMANCE OF THE DATA FILES OR SOFTWARE.
 *
 * Except as contained in this notice, the name of a copyright holder
 * shall not be used in advertising or otherwise to promote the sale,
 * use or other dealings in these Data Files or Software without prior
 * written authorization of the copyright holder.
 */

package sun.util.resources.cldr.ext;

import sun.util.resources.OpenListResourceBundle;

public class CurrencyNames_lag extends OpenListResourceBundle {
    @Override
    protected final Object[][] getContents() {
        final Object[][] data = new Object[][] {
            { "TZS", "TSh" },
            { "aed", "Dirih\u00e1amu ya \u0244temi wa K\u0268ar\u00e1abu" },
            { "aoa", "Kw\u00e1anza ya Ang\u00f3ola" },
            { "aud", "D\u00f3ola ya Ausitereel\u00eda" },
            { "bhd", "Din\u00e1ari ya Bahar\u00e9eni" },
            { "bif", "Far\u00e1anga ya Bur\u00faundi" },
            { "bwp", "P\u00faula ya Botisw\u00e1ana" },
            { "cad", "D\u00f3ola ya K\u00e1nada" },
            { "cdf", "Far\u00e1anga ya K\u00f3ongo" },
            { "chf", "Far\u00e1aka ya Usw\u00edisi" },
            { "cny", "Y\u00faani Renim\u00ednibi ya Ch\u00edina" },
            { "cve", "Esik\u00faudo ya Kepuv\u00e9ede" },
            { "djf", "Far\u00e1anga ya Jib\u00f3uti" },
            { "dzd", "Din\u00e1airi ya Alij\u00e9ria" },
            { "egp", "P\u00e1undi ya M\u00edsiri" },
            { "ern", "N\u00e1k\u0268fa ya Eriterea" },
            { "etb", "B\u00ediri ya \u0244hab\u00e9eshi" },
            { "eur", "Y\u00fauro" },
            { "gbp", "P\u00e1undi ya \u0244\u0268ng\u0268r\u00e9esa" },
            { "ghc", "S\u00e9edi ya G\u00e1ana" },
            { "gmd", "Dal\u00e1asi ya G\u00e1mbia" },
            { "gns", "Far\u00e1anga ya G\u00edine" },
            { "inr", "Rup\u00eda ya \u00cdndia" },
            { "jpy", "Y\u00e9eni ya Jap\u00e1ani" },
            { "kes", "Shil\u00edingi ya K\u00e9enya" },
            { "kmf", "Far\u00e1anga ya Kom\u00f3oro" },
            { "lrd", "D\u00f3ola ya Lib\u00e9ria" },
            { "lsl", "L\u00f3oti ya Les\u00f3oto" },
            { "lyd", "Din\u00e1ari ya L\u00edbia" },
            { "mad", "Dirih\u00e1amu ya Mor\u00f3oko" },
            { "mga", "Mp\u00eda ya bukini" },
            { "mro", "Ungw\u00ediya ya Morit\u00e1nia (1973\u20132017)" },
            { "mru", "Ungw\u00ediya ya Morit\u00e1nia" },
            { "mur", "Rup\u00eda ya Mor\u00edisi" },
            { "mwk", "Kw\u00e1acha ya Mal\u00e1awi" },
            { "mzm", "Metik\u00e1ali ya Musumb\u00ediji" },
            { "nad", "D\u00f3ola ya Nam\u00edbia" },
            { "ngn", "Na\u00edira ya Niij\u00e9ria" },
            { "rwf", "Far\u00e1anga ya Rw\u00e1anda" },
            { "sar", "Riy\u00e1ali ya Saud\u00eda" },
            { "scr", "Rup\u00eda ya Shelish\u00e9eli" },
            { "sdg", "P\u00e1undi ya Sud\u00e1ani" },
            { "shp", "P\u00e1undi ya M\u0289takat\u00edifu Hel\u00e9ena" },
            { "sle", "Le\u00f3oni" },
            { "sll", "Le\u00f3oni (1964\u20142022)" },
            { "sos", "Shil\u00edingi ya Som\u00e1lia" },
            { "std", "D\u00f3bura ya SaoT\u00f3ome na Pir\u00ednsipe (1977\u20132017)" },
            { "stn", "D\u00f3bura ya SaoT\u00f3ome na Pir\u00ednsipe" },
            { "szl", "Lileng\u00e9eni" },
            { "tnd", "Din\u00e1ari ya Tun\u00edsia" },
            { "tzs", "Shil\u00edingi ya Taansan\u00eda" },
            { "ugx", "Shil\u00edingi ya Ug\u00e1anda" },
            { "usd", "D\u00f3ola ya Amer\u0268\u0301ka" },
            { "xaf", "Far\u00e1anga ya CFA BEAC" },
            { "xof", "Far\u00e1anga ya CFA BCEAO" },
            { "zar", "R\u00e1andi ya Af\u0268r\u0268ka ya Saame" },
            { "zmk", "Kw\u00e1cha ya S\u00e1mbia (1968\u20132012)" },
            { "zmw", "Kw\u00e1cha ya S\u00e1mbia" },
            { "zwd", "D\u00f3ola ya Simb\u00e1abwe" },
        };
        return data;
    }
}
